==> spip_3.2.11.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'إدراج A مع نبر الاطالة: À',
	'barre_adresse' => 'عنوان',
	'barre_aide' => 'استخدم شريط اختصارات الكتابة لإغناء تصميم صفحتك',
	'barre_alignerdroite' => 'محاذاة الى [/اليمين/]',
	'barre_ancres' => 'إدارة المراسي',
	'barre_barre' => 'شطب النص',
	'barre_bulle' => 'بالون تعليمات',
	'barre_c_cedille_maj' => 'ادراج C كبير مع علامة لفظية: Ç',
	'barre_cadre' => 'وضع في &lt;cadre&gt;مجال إدخال نصوص&lt;/cadre&gt;',
	'barre_caracteres' => 'حروف خاصة',
	'barre_centrer' => '[|توسيط|] الفقرة',
	'barre_chercher' => 'بحث واستبدال',
	'barre_clean' => 'تنظيف الرموز البرمجية من كل علامات HTML',
	'barre_code' => 'تنسيق &lt;code&gt;مقطع رموز برمجية&lt;/code&gt;',
	'barre_desindenter' => 'إلغاء إزاحة لائحة',
	'barre_e_accent_aigu' => 'ادراج E كبير مع نبر خفيض - È',
	'barre_e_accent_grave' => 'إدراج E كبير مع نبر الاطالة: È',
	'barre_ea' => 'ادراج e داخل a: æ',
	'barre_ea_maj' => 'ادراج E كبير داخل A كبير: Æ',
	'barre_encadrer' => 'وضع في [(إطار)]',
	'barre_eo' => 'ادراج e داخل o: œ',
	'barre_eo_maj' => 'ادراج E كبير داخل O كبير: Œ',
	'barre_euro' => 'ادراج رمز €',
	'barre_exposant' => 'تحويل الى &lt;sup&gt;نص فوقي&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'تنسيقات خاصة',
	'barre_galerie' => 'فتح صالة العرض',
	'barre_gestion_anc_bulle' => 'بالون تعليمات المرساة',
	'barre_gestion_anc_caption' => 'إدارة المراسي',
	'barre_gestion_anc_cible' => 'المرساة الهدف',
	'barre_gestion_anc_inserer' => 'تحويل الى مرساة',
	'barre_gestion_anc_nom' => 'اسم المرساة',
	'barre_gestion_anc_pointer' => 'التصويب الى مرساة',
	'barre_gestion_caption' => 'وصف وملخص',
	'barre_gestion_colonne' => 'عدد الأعمدة',
	'barre_gestion_cr_casse' => 'تطابق حجم الحروف',
	'barre_gestion_cr_changercasse' => 'تغيير حجم الحروف',
	'barre_gestion_cr_changercassemajuscules' => 'تحويل الى الحروف كبيرة',
	'barre_gestion_cr_changercasseminuscules' => 'تحويل الى الحروف صغيرة',
	'barre_gestion_cr_chercher' => 'بحث',
	'barre_gestion_cr_entier' => 'كلمة كاملة',
	'barre_gestion_cr_remplacer' => 'استبدال',
	'barre_gestion_cr_tout' => 'استبدال الكل',
	'barre_gestion_entete' => 'ترويسة',
	'barre_gestion_ligne' => 'عدد السطور',
	'barre_gestion_taille' => 'حجم ثابت',
	'barre_glossaire' => 'مدخل في [?المعجم] (ويكيبيديا)',
	'barre_gras' => '{{اسود}}',
	'barre_guillemets' => 'احاطة «بعلامتي اقتباس مزدوجة»',
	'barre_guillemets_simples' => 'وضع بين "علامتي إقتباس مزدوجة من المستوى الثاني"',
	'barre_indenter' => 'إزاحة لائحة',
	'barre_inserer_cadre' => 'إدراج رموز منسقة مسبقاً (إطار)',
	'barre_inserer_caracteres' => 'إدراج حروف محددة',
	'barre_inserer_code' => 'إدراج رموز برمجية (رموز)',
	'barre_intertitre' => 'تحويل الى {{{عنوان فقرة}}}',
	'barre_italic' => '{مائل}',
	'barre_langue' => 'لغة مختصرة',
	'barre_lien' => 'تحويل الى [وصلة هايبرتكست->http://...]',
	'barre_lien_externe' => 'رابط خارجي',
	'barre_lien_input' => 'الرجاء ادخال عنوان الوصلة (يمكنك ادخال عنوان نسيج على شكل http://www.mysite.com او ادخال رقم مقال من الموقع الحالي فقط).',
	'barre_liste_ol' => 'تحويل الى لائحة مرقمة',
	'barre_liste_ul' => 'تحويل الى لائحة',
	'barre_lorem_ipsum' => 'إدراج فقرة زائفة',
	'barre_lorem_ipsum_3' => 'إدراج ثلاث فقرات زائفة',
	'barre_miseenevidence' => '[*إبراز*] النص',
	'barre_note' => 'تحويل الى [[حاشية]]',
	'barre_paragraphe' => 'انشاء فقرة',
	'barre_petitescapitales' => 'تحويل الى &lt;sc&gt;حروف كبيرة مصغرة&lt;/sc&gt;',
	'barre_poesie' => 'تنسيق &lt;poesie&gt;شعر&lt;/poesie&gt;',
	'barre_preview' => 'معاينة',
	'barre_quote' => '<quote>اقتباس رسالة</quote>',
	'barre_stats' => 'عرض احصاءات النص',
	'barre_tableau' => 'إدراج جدول أو تعديل جدول (تحديده أولاً)',

	// C
	'config_info_enregistree' => 'تم حفظ الإعداد',

	// E
	'editer' => 'تحرير',
	'explication_barre_outils_public' => 'يتم تحميل أوامر أوراق الأنماط وجافاسكريبت (إضافة الريشة، Porte Plume) في الموقع العمومي لتوقر استخدام شريط الأدوات في استمارات المنتديات والأقلام العمومية وملحقات أخرى أذا سمحت إعداداتها بذلك.',
	'explication_barre_outils_public_2' => 'يمكنك اختيار عدم تحميل هذه الأوامر لتخفيف وزن الصفحات العمومية.
عندها، مهما تكن إعدادات المنتديات او الأقلام او الملحقات، لن يظهر اي شريط أدوات من الريشة في الموقع العمومي.',

	// I
	'info_barre_outils_public' => 'شريط الأدوات العمومي',
	'info_porte_plume_titre' => 'إعداد شريط الأدوات',

	// L
	'label_barre_outils_public_non' => 'عدم تحميل أوامر شريط الأدوات في الموقع العمومي',
	'label_barre_outils_public_oui' => 'تحميل أوامر شريط الأدوات في الموقع العمومي',

	// V
	'voir' => 'معاينة'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// B
	'barre_a_accent_grave' => 'إدراج A مع نبر الاطالة: À',
	'barre_adresse' => 'عنوان',
	'barre_aide' => 'استخدم شريط اختصارات الكتابة لإغناء تصميم صفحتك',
	'barre_alignerdroite' => 'محاذاة الى [/اليمين/]',
	'barre_ancres' => 'إدارة المراسي',
	'barre_barre' => 'شطب النص',
	'barre_bulle' => 'بالون تعليمات',
	'barre_c_cedille_maj' => 'ادراج C كبير مع علامة لفظية: Ç',
	'barre_cadre' => 'وضع في &lt;cadre&gt;مجال إدخال نصوص&lt;/cadre&gt;',
	'barre_caracteres' => 'حروف خاصة',
	'barre_centrer' => '[|توسيط|] الفقرة',
	'barre_chercher' => 'بحث واستبدال',
	'barre_clean' => 'تنظيف الرموز البرمجية من كل علامات HTML',
	'barre_code' => 'تنسيق &lt;code&gt;مقطع رموز برمجية&lt;/code&gt;',
	'barre_desindenter' => 'إلغاء إزاحة لائحة',
	'barre_e_accent_aigu' => 'ادراج E كبير مع نبر خفيض - È',
	'barre_e_accent_grave' => 'إدراج E كبير مع نبر الاطالة: È',
	'barre_ea' => 'ادراج e داخل a: æ',
	'barre_ea_maj' => 'ادراج E كبير داخل A كبير: Æ',
	'barre_encadrer' => 'وضع في [(إطار)]',
	'barre_eo' => 'ادراج e داخل o: œ',
	'barre_eo_maj' => 'ادراج E كبير داخل O كبير: Œ',
	'barre_euro' => 'ادراج رمز €',
	'barre_exposant' => 'تحويل الى &lt;sup&gt;نص فوقي&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'تنسيقات خاصة',
	'barre_galerie' => 'فتح صالة العرض',
	'barre_gestion_anc_bulle' => 'بالون تعليمات المرساة',
	'barre_gestion_anc_caption' => 'إدارة المراسي',
	'barre_gestion_anc_cible' => 'المرساة الهدف',
	'barre_gestion_anc_inserer' => 'تحويل الى مرساة',
	'barre_gestion_anc_nom' => 'اسم المرساة',
	'barre_gestion_anc_pointer' => 'التصويب الى مرساة',
	'barre_gestion_caption' => 'وصف وملخص',
	'barre_gestion_colonne' => 'عدد الأعمدة',
	'barre_gestion_cr_casse' => 'تطابق حجم الحروف',
	'barre_gestion_cr_changercasse' => 'تغيير حجم الحروف',
	'barre_gestion_cr_changercassemajuscules' => 'تحويل الى الحروف كبيرة',
	'barre_gestion_cr_changercasseminuscules' => 'تحويل الى الحروف صغيرة',
	'barre_gestion_cr_chercher' => 'بحث',
	'barre_gestion_cr_entier' => 'كلمة كاملة',
	'barre_gestion_cr_remplacer' => 'استبدال',
	'barre_gestion_cr_tout' => 'استبدال الكل',
	'barre_gestion_entete' => 'ترويسة',
	'barre_gestion_ligne' => 'عدد السطور',
	'barre_gestion_taille' => 'حجم ثابت',
	'barre_glossaire' => 'مدخل في [?المعجم] (ويكيبيديا)',
	'barre_gras' => '{{اسود}}',
	'barre_guillemets' => 'احاطة «بعلامتي اقتباس مزدوجة»',
	'barre_guillemets_simples' => 'وضع بين "علامتي إقتباس مزدوجة من المستوى الثاني"',
	'barre_indenter' => 'إزاحة لائحة',
	'barre_inserer_cadre' => 'إدراج رموز منسقة مسبقاً (```)',
	'barre_inserer_caracteres' => 'إدراج حروف محددة',
	'barre_inserer_code' => 'إدراج رموز برمجية (`)',
	'barre_intertitre' => 'تحويل الى {{{عنوان فقرة}}}',
	'barre_italic' => '{مائل}',
	'barre_langue' => 'لغة مختصرة',
	'barre_lien' => 'تحويل الى [وصلة هايبرتكست->http://...]',
	'barre_lien_externe' => 'رابط خارجي',
	'barre_lien_input' => 'الرجاء ادخال عنوان الوصلة (يمكنك ادخال عنوان نسيج على شكل http://www.mysite.com او ادخال رقم مقال من الموقع الحالي فقط).',
	'barre_liste_ol' => 'تحويل الى لائحة مرقمة',
	'barre_liste_ul' => 'تحويل الى لائحة',
	'barre_lorem_ipsum' => 'إدراج فقرة زائفة',
	'barre_lorem_ipsum_3' => 'إدراج ثلاث فقرات زائفة',
	'barre_miseenevidence' => '[*إبراز*] النص',
	'barre_note' => 'تحويل الى [[حاشية]]',
	'barre_paragraphe' => 'انشاء فقرة',
	'barre_petitescapitales' => 'تحويل الى &lt;sc&gt;حروف كبيرة مصغرة&lt;/sc&gt;',
	'barre_poesie' => 'تنسيق &lt;poesie&gt;شعر&lt;/poesie&gt;',
	'barre_preview' => 'معاينة',
	'barre_quote' => '<quote>اقتباس رسالة</quote>',
	'barre_stats' => 'عرض احصاءات النص',
	'barre_tableau' => 'إدراج جدول أو تعديل جدول (تحديده أولاً)',

	// C
	'config_info_enregistree' => 'تم حفظ الإعداد',

	// E
	'editer' => 'تحرير',
	'explication_barre_outils_public' => 'يتم تحميل أوامر أوراق الأنماط وجافاسكريبت (إضافة الريشة، Porte Plume) في الموقع العمومي لتوقر استخدام شريط الأدوات في استمارات المنتديات والأقلام العمومية وملحقات أخرى أذا سمحت إعداداتها بذلك.',
	'explication_barre_outils_public_2' => 'يمكنك اختيار عدم تحميل هذه الأوامر لتخفيف وزن الصفحات العمومية.
عندها، مهما تكن إعدادات المنتديات او الأقلام او الملحقات، لن يظهر اي شريط أدوات من الريشة في الموقع العمومي.',

	// I
	'info_barre_outils_public' => 'شريط الأدوات العمومي',
	'info_porte_plume_titre' => 'إعداد شريط الأدوات',

	// L
	'label_barre_outils_public_non' => 'عدم تحميل أوامر شريط الأدوات في الموقع العمومي',
	'label_barre_outils_public_oui' => 'تحميل أوامر شريط الأدوات في الموقع العمومي',

	// V
	'voir' => 'معاينة',
];
